﻿using System;
using System.Collections.Generic;
using System.Drawing;
using System.Linq;

namespace CV2
{
    class Program
    {
        static void Main(string[] args)
        {
            // Anonymous and Extension methods
            Calculator c = new Calculator();

            c.Write(8, 3, delegate (int x, int y) { return x * y; });
            c.Write(8, 3, (x, y) => x / y);

            c.OnSetXY += (s, e) => { Console.WriteLine("Lambda subscriber {0}", e.SetXYDate); };
            c.SetXY(5, 3);

            Console.WriteLine(c.Mod());

            // LINQ
            int[] array = { 18, 5, 4, 25, 74, 154, 9, 57, 38, 666, 42 };
            List<int> resClassic = new List<int>();

            foreach (int item in array)
                if (item > 10 && item % 2 == 0)
                    resClassic.Add(item * 2);

            resClassic.Sort();
            var resExtension = array.Where(i => i > 10 && i % 2 == 0).OrderBy(i => i).Select(i => i * 2);
            var resLinq = from i in array
                          where i > 10 && i % 2 == 0
                          orderby i
                          select i * 2;

            Console.WriteLine(String.Join(", ", resClassic));
            Console.WriteLine(String.Join(", ", resExtension));
            Console.WriteLine(String.Join(", ", resLinq));

            // Drawing
            using (Bitmap b = new Bitmap(1000, 625))
            using (Graphics g = Graphics.FromImage(b))
            {
                Pen pR = new Pen(Color.Red, 10);
                Pen pB = new Pen(Color.Blue, 10);
                Pen pK = new Pen(Color.Black, 10);

                g.DrawRectangle(pR, 0, 0, 1000, 625);
                g.DrawEllipse(pB, 250, 100, 100, 100);
                g.DrawEllipse(pB, 650, 100, 100, 100);
                g.DrawEllipse(pK, 475, 175, 50, 200);

                List<Point> mouth = new List<Point>();
                mouth.Add(new Point(250, 400));
                mouth.Add(new Point(350, 550));
                mouth.Add(new Point(650, 550));
                mouth.Add(new Point(750, 400));

                g.DrawLines(pR, mouth.ToArray());

                g.DrawString("AT.NET 2016", new Font("Arial", 32), Brushes.Black, new PointF(715, 570));

                b.Save("img.png");
            }
        }
    }
}
